@@ -38,7 +38,7 @@ diri.contour <- function(a, n = 100, x = NULL) {
         w3 <- 2 * x2[j] / sqrt3
         w2 <- x1[i] - x2[j]/sqrt3
         w1 <- 1 - w2 - w3
-        w <- round(c(w1, w2, w3), 6)
+        w <- c(w1, w2, w3)
         can <- prod( w^(a - 1) ) / be
         if (abs(can) < Inf)  mat[i, j] <- can
       }
@@ -59,7 +59,8 @@ diri.contour <- function(a, n = 100, x = NULL) {
   	nam <- colnames(x)
   	if ( is.null(nam) )  nam <- paste("X", 1:3, sep = "")
   	points(b[, 1], b[, 2], type = "l", xlab = " ", ylab = " ")
-    text(b[1, 1], b[1, 2] + 0.02, nam[3], cex = 1)
+  	text( b[1, 1], b[1, 2] + 0.02, nam[3], cex = 1 )
+  	text( b[2:3, 1], b[2:3, 2] - 0.02, nam[1:2], cex = 1 )
   }
 
 }
