@@ -10,7 +10,7 @@ frechet <- function(x, a) {
   ## x contains the compositional data
   ## a is the power parameter, usually between -1 and 1
   if ( length(a) == 1 ) {
-    if ( a == 0 ) {
+    if ( abs(a) < 1e-12 ) {
       m1 <- exp( Rfast::colmeans( Rfast::Log(x) ) )
       m <- m1 / sum( m1 )  ## closed geometric mean
     } else {
@@ -24,7 +24,7 @@ frechet <- function(x, a) {
     m <- matrix( nrow = length(a), ncol = dim(x)[2] )
     rownames(m) <- paste("alpha=", a, sep = "")
     for ( i in 1:length(a) ) {
-      if ( a[i] == 0 ) {
+      if ( abs(a[i]) < 1e-12 ) {
         m1 <- exp( Rfast::colmeans( Rfast::Log(x) ) )
         m[i, ] <- m1 / sum( m1 )  ## closed geometric mean
       } else {
